def lemons():
    print('Lemonade')

def words_to_live_by(given):
    if given == 'Lemons':
        return 'Lemonade, obviously'
    if given == 'Happiness':
        return 'Just chill'
    else:
        return f'{given}ade'


def what_is_the_loneliest_number():
    return 1